@@ -1,12 +1,12 @@
 package App::LintPrereqs;
 
-our $DATE = '2015-05-15'; # DATE
-our $VERSION = '0.26'; # VERSION
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.27'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any qw($log);
+use Log::Any::IfLOG qw($log);
 
 use Config::IniFiles;
 use File::Find;
@@ -315,7 +315,7 @@ App::LintPrereqs - Check extraneous/missing prerequisites in dist.ini
 
 =head1 VERSION
 
-This document describes version 0.26 of App::LintPrereqs (from Perl distribution App-LintPrereqs), released on 2015-05-15.
+This document describes version 0.27 of App::LintPrereqs (from Perl distribution App-LintPrereqs), released on 2015-08-17.
 
 =head1 SYNOPSIS
 
